from jupyterhub_idle_culler import main

if __name__ == "__main__":
    main()
